FlutterKeycloak class
A Flutter plugin to manage the keycloak authentication, managing on the local storage the tokens and the credentials
Constructors
- FlutterKeycloak({required String clientId, required String clientSecret})
Properties
- clientId ↔ String
-
getter/setter pair
- clientSecret ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConf(
String url) → Future - Get KeyCloak Realm Configuration
-
getUserInfo(
{dynamic inputConf, dynamic inputTokens}) → Future - Get User Info
-
login(
dynamic conf, String username, String password, {String? scope, bool storeInfo = true}) → Future - Init the login process
-
logout(
{bool destroySession = true, dynamic inputConf, dynamic inputTokens}) → Future - Logs the user out
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refreshLogin(
{dynamic inputConf, dynamic inputCredentials, dynamic scope, dynamic storeInfo = true}) → Future - Automatically redo the login
-
refreshToken(
{dynamic inputConf, dynamic inputTokens}) → Future - Gets the refresh token
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited